resolve_groups

Function resolve_groups 

pub fn resolve_groups(
    group_names: &[String],
    groups: &BTreeMap<String, Vec<String>>,
    all_repos: &[RepoEntry],
) -> Result<(Vec<RepoEntry>, Vec<String>)>
Resolve named groups to a set of matching repos.

Returns (matched_repos, warnings) where warnings describe repo names that could not be found in the registry. Errors if any group name is unknown (not defined in config).